==> com.deepin.lianliankan_1.0.8.orig.tar.xz: com.deepin.lianliankan-1.0.8/translations/deepin-lianliankan_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>CloseWindowDialog</name>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="47"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>Jeni i sigurt se doni të braktisni lojën?</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="55"/>
        <source>Keep Playing</source>
        <translation>Vazhdo Lojën</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="56"/>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
</context>
<context>
    <name>GameoverBlurEffectWidget</name>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="105"/>
        <source>Play Again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="106"/>
        <source>Have a Rest</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <location filename="../src/main.cpp" line="65"/>
        <location filename="../src/main.cpp" line="66"/>
        <source>LianLianKan</source>
        <translation>LianLianKan</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Lianliankan is a puzzle game.</source>
        <translation>Lianliankan është një lojë puzzle.</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../src/source/mainpage.cpp" line="45"/>
        <source>Easy</source>
        <translation>E lehtë</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="46"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="47"/>
        <source>Hard</source>
        <translation>E vështirë</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="65"/>
        <source>Select Level</source>
        <translation>Përzgjidhni Nivel</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="108"/>
        <source>FAIL</source>
        <translation>HUMBJE</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="111"/>
        <source>VICTORY</source>
        <translation>FITORE</translation>
    </message>
</context>
</TS>

==> com.deepin.lianliankan_1.0.11.orig.tar.xz: com.deepin.lianliankan-1.0.11/translations/deepin-lianliankan_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>CloseWindowDialog</name>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="47"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>Jeni i sigurt se doni të braktisni lojën?</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="55"/>
        <source>Keep Playing</source>
        <translation>Vazhdo Lojën</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="56"/>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
</context>
<context>
    <name>GameoverBlurEffectWidget</name>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="105"/>
        <source>Play Again</source>
        <translation>Luajeni Prapë</translation>
    </message>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="106"/>
        <source>Have a Rest</source>
        <translation>Bëni Ca Pushim</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <location filename="../src/main.cpp" line="65"/>
        <location filename="../src/main.cpp" line="66"/>
        <source>LianLianKan</source>
        <translation>LianLianKan</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Lianliankan is a puzzle game.</source>
        <translation>Lianliankan është një lojë puzzle.</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../src/source/mainpage.cpp" line="45"/>
        <source>Easy</source>
        <translation>E lehtë</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="46"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="47"/>
        <source>Hard</source>
        <translation>E vështirë</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="65"/>
        <source>Select Level</source>
        <translation>Përzgjidhni Nivel</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="108"/>
        <source>FAIL</source>
        <translation>HUMBJE</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="111"/>
        <source>VICTORY</source>
        <translation>FITORE</translation>
    </message>
</context>
</TS>
